@@ -30,26 +30,39 @@ read_config(Animation_WallpaperPrivate *priv) {
     GConfClient *gconf_client = NULL;
     gchar *tmp = NULL;
     GConfValue *value = NULL;
-    
+    gint id = priv->view;
+    gchar * str = NULL;
+
     gconf_client = gconf_client_get_default();
     if (!gconf_client) {
         fprintf(stderr, _("Failed to initialize GConf. Quitting.\n"));
         return -1;
     }
     /* get Theme default Modern */
+    str = g_strdup_printf("%s%i", GCONF_KEY_THEME, id);
     tmp = gconf_client_get_string(gconf_client,
-                                  GCONF_KEY_THEME, NULL);
+                                  str, NULL);
+    if (str){ 
+        g_free(str);
+        str = NULL;
+    }    
     if (tmp){
         priv->theme = tmp;
     }else
         priv->theme = g_strdup("Modern");
     /* get Rich animation default TRUE */
-    value = gconf_client_get(gconf_client, GCONF_KEY_RANIMATION, NULL);
+    str = g_strdup_printf("%s%i", GCONF_KEY_RANIMATION, id);
+    value = gconf_client_get(gconf_client, str, NULL);
+    if (str){ 
+        g_free(str);
+        str = NULL;
+    } 
     if (value) {
         priv->rich_animation = gconf_value_get_bool(value);
         gconf_value_free(value);
     } else
         priv->rich_animation = TRUE;
+    
 
     return 0;
 }
@@ -59,21 +72,36 @@ void
 save_config(Animation_WallpaperPrivate *priv) {
 
     GConfClient *gconf_client;
+    gchar * str = NULL;
+    gint id = priv->view;
+
     gconf_client = gconf_client_get_default();
     if (!gconf_client) {
         fprintf(stderr, _("Failed to initialize GConf. Quitting.\n"));
         return;
     }
-    /* Save Weather source name. */
-    if (priv->theme)
+    
+    if (priv->theme){
+        str = g_strdup_printf("%s%i", GCONF_KEY_THEME, id);
         gconf_client_set_string(gconf_client,
-                  GCONF_KEY_THEME,
+                  str,
                   priv->theme, NULL);
+        if (str){
+            g_free(str);
+            str = NULL;
+        }
+    }
+
+    str = g_strdup_printf("%s%i", GCONF_KEY_RANIMATION, id);
     if (priv->rich_animation)
         gconf_client_set_bool(gconf_client,
-                              GCONF_KEY_RANIMATION, TRUE, NULL);
+                              str, TRUE, NULL);
     else
         gconf_client_set_bool(gconf_client,
-                              GCONF_KEY_RANIMATION, FALSE, NULL);
-
+                              str, FALSE, NULL);
+    if (str){
+        g_free(str);
+        str = NULL;
+    }
+    
 }
