@@ -354,7 +354,7 @@ run_long_timeout(AWallpaperPlugin *desktop_plugin)
 
     if (!desktop_plugin->priv->scene)
 	return;
-    //fprintf(stderr, "!!!run long timeout short_timer=%d\n", desktop_plugin->priv->short_timer);
+//    fprintf(stderr, "!!!run long timeout short_timer=%d\n", desktop_plugin->priv->short_timer);
     if (desktop_plugin->priv->scene->daytime != daytime){
         desktop_plugin->priv->scene->daytime = daytime;
         tmp = desktop_plugin->priv->scene->actors;
@@ -454,7 +454,7 @@ animation_wallpaper_plugin_init (AWallpaperPlugin *desktop_plugin)
     livewp_initialize_dbus(priv);
 
     priv->desktop_plugin = desktop_plugin;
-    priv->visible = TRUE;
+    priv->visible = FALSE;
     priv->short_timer = 0;
     priv->xapplet = 0;
     priv->yapplet = 0;
