@@ -24,14 +24,14 @@
 /*******************************************************************************/
 #include "livewp-common.h"
 #include <unistd.h>
-void lw_settings(Animation_WallpaperPrivate *priv, gpointer data);
+void lw_main_settings(Animation_WallpaperPrivate *priv, gpointer data);
 void save_config(Animation_WallpaperPrivate *priv);
-gboolean check_applet_state(void);
+gboolean check_applet_state(gint number);
 void reload_scene(AWallpaperPlugin *desktop_plugin);
 GtkWidget* create_settings(void);
 void show_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv);
-void start_applet(void);
-void stop_applet(void);
+void start_applet(gint number);
+void stop_applet(gint number);
 void send_dbus_signal (Animation_WallpaperPrivate *priv, const gchar *interface,
                   const gchar *path, const gchar *member);
 
